summaryrefslogtreecommitdiffstats
path: root/kradio3/plugins
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-18 18:13:01 -0600
committerTimothy Pearson <[email protected]>2011-12-18 18:13:01 -0600
commit8d4453deaa5f97e1bbe76ea45fdcac6121da8c9d (patch)
tree98a944d593e1998726e1728dd298d40123f30059 /kradio3/plugins
parent6df9eac4b9928768bf0c3dc988bac1c0c1fbb685 (diff)
downloadtderadio-8d4453deaa5f97e1bbe76ea45fdcac6121da8c9d.tar.gz
tderadio-8d4453deaa5f97e1bbe76ea45fdcac6121da8c9d.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kradio3/plugins')
-rw-r--r--kradio3/plugins/alsa-sound/alsa-mixer-element-ui.ui16
-rw-r--r--kradio3/plugins/alsa-sound/alsa-sound-configuration-ui.ui4
-rw-r--r--kradio3/plugins/alsa-sound/alsa-sound-configuration.cpp4
-rw-r--r--kradio3/plugins/gui-error-log/errorlog.cpp8
-rw-r--r--kradio3/plugins/gui-quickbar/buttonflowlayout.cpp16
-rw-r--r--kradio3/plugins/gui-quickbar/buttonflowlayout.h6
-rw-r--r--kradio3/plugins/gui-quickbar/quickbar.cpp8
-rw-r--r--kradio3/plugins/gui-standard-display/displaycfg.cpp20
-rw-r--r--kradio3/plugins/gui-standard-display/radioview.cpp8
-rw-r--r--kradio3/plugins/gui-standard-display/radioview_frequencyradio.cpp12
-rw-r--r--kradio3/plugins/radio/radio-configuration-ui.ui16
-rw-r--r--kradio3/plugins/radio/radio-configuration.cpp2
-rw-r--r--kradio3/plugins/recording/encoder_mp3.cpp2
-rw-r--r--kradio3/plugins/recording/encoder_ogg.cpp2
-rw-r--r--kradio3/plugins/recording/recording-configuration-ui.ui20
-rw-r--r--kradio3/plugins/recording/recording-datamonitor.cpp14
-rw-r--r--kradio3/plugins/recording/recording-monitor.cpp6
-rw-r--r--kradio3/plugins/recording/recording-monitor.h2
-rw-r--r--kradio3/plugins/recording/recording.cpp2
-rw-r--r--kradio3/plugins/streaming/streaming-configuration-ui.ui46
-rw-r--r--kradio3/plugins/timecontrol/timecontrol-configuration-ui.ui8
-rw-r--r--kradio3/plugins/timecontrol/timecontrol-configuration.cpp2
-rw-r--r--kradio3/plugins/timecontrol/timecontrol.cpp6
-rw-r--r--kradio3/plugins/timeshifter/timeshifter-configuration-ui.ui12
-rw-r--r--kradio3/plugins/v4lradio/v4lradio-configuration-ui.ui32
25 files changed, 137 insertions, 137 deletions
diff --git a/kradio3/plugins/alsa-sound/alsa-mixer-element-ui.ui b/kradio3/plugins/alsa-sound/alsa-mixer-element-ui.ui
index ebdd9a1..6d15369 100644
--- a/kradio3/plugins/alsa-sound/alsa-mixer-element-ui.ui
+++ b/kradio3/plugins/alsa-sound/alsa-mixer-element-ui.ui
@@ -37,7 +37,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -54,7 +54,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>1</width>
<height>40</height>
@@ -85,7 +85,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>1</width>
<height>40</height>
@@ -102,7 +102,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -129,7 +129,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>11</width>
<height>20</height>
@@ -157,7 +157,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>11</width>
<height>20</height>
@@ -184,7 +184,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -236,7 +236,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
diff --git a/kradio3/plugins/alsa-sound/alsa-sound-configuration-ui.ui b/kradio3/plugins/alsa-sound/alsa-sound-configuration-ui.ui
index c15e91d..e487fb1 100644
--- a/kradio3/plugins/alsa-sound/alsa-sound-configuration-ui.ui
+++ b/kradio3/plugins/alsa-sound/alsa-sound-configuration-ui.ui
@@ -50,7 +50,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>5</height>
@@ -259,7 +259,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/kradio3/plugins/alsa-sound/alsa-sound-configuration.cpp b/kradio3/plugins/alsa-sound/alsa-sound-configuration.cpp
index 88c4d57..e1905ec 100644
--- a/kradio3/plugins/alsa-sound/alsa-sound-configuration.cpp
+++ b/kradio3/plugins/alsa-sound/alsa-sound-configuration.cpp
@@ -135,13 +135,13 @@ void AlsaSoundConfiguration::slotCaptureCardSelected(const TQString &cardname)
delete m_groupMixerSubFrame;
m_groupMixerSubFrame = new TQFrame(m_groupMixerScrollView->viewport());
- m_groupMixerSubFrame->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Maximum);
+ m_groupMixerSubFrame->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Maximum);
m_groupMixerScrollView->addChild(m_groupMixerSubFrame);
int rows = 1;
int cols = (all_list.count()+rows-1)/rows;
m_groupMixerLayout = new TQGridLayout( m_groupMixerSubFrame, rows, cols, 0, 0 );
- m_groupMixerLayout->tqsetAlignment( TQt::AlignBottom );
+ m_groupMixerLayout->setAlignment( TQt::AlignBottom );
int idx = 0;
for (TQValueListConstIterator<TQString> it = all_list.begin(); it != all_list.end(); ++it, ++idx) {
diff --git a/kradio3/plugins/gui-error-log/errorlog.cpp b/kradio3/plugins/gui-error-log/errorlog.cpp
index b675d14..e593192 100644
--- a/kradio3/plugins/gui-error-log/errorlog.cpp
+++ b/kradio3/plugins/gui-error-log/errorlog.cpp
@@ -183,7 +183,7 @@ void ErrorLog::hideEvent(TQHideEvent *e)
bool ErrorLog::logError (const TQString &s)
{
- m_teErrors->append("<i>" + TQDateTime::tqcurrentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
+ m_teErrors->append("<i>" + TQDateTime::currentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
if (init_done) {
showPage(PAGE_ID_ERROR);
show();
@@ -193,19 +193,19 @@ bool ErrorLog::logError (const TQString &s)
bool ErrorLog::logWarning(const TQString &s)
{
- m_teWarnings->append("<i>" + TQDateTime::tqcurrentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
+ m_teWarnings->append("<i>" + TQDateTime::currentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
return true;
}
bool ErrorLog::logInfo (const TQString &s)
{
- m_teInfos->append("<i>" + TQDateTime::tqcurrentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
+ m_teInfos->append("<i>" + TQDateTime::currentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
return true;
}
bool ErrorLog::logDebug (const TQString &s)
{
- m_teDebug->append("<i>" + TQDateTime::tqcurrentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
+ m_teDebug->append("<i>" + TQDateTime::currentDateTime().toString(Qt::ISODate) + "</i> " + s + "\n");
return true;
}
diff --git a/kradio3/plugins/gui-quickbar/buttonflowlayout.cpp b/kradio3/plugins/gui-quickbar/buttonflowlayout.cpp
index 4cd8dd0..528f9c5 100644
--- a/kradio3/plugins/gui-quickbar/buttonflowlayout.cpp
+++ b/kradio3/plugins/gui-quickbar/buttonflowlayout.cpp
@@ -104,9 +104,9 @@ bool ButtonFlowLayout::hasHeightForWidth() const
return TRUE;
}
-TQSize ButtonFlowLayout::tqsizeHint() const
+TQSize ButtonFlowLayout::sizeHint() const
{
- return tqminimumSize();
+ return minimumSize();
}
TQSizePolicy::ExpandData ButtonFlowLayout::expanding() const
@@ -154,8 +154,8 @@ int ButtonFlowLayout::doLayout( const TQRect &r, bool testonly )
it.toFirst();
while ( (o=it.current()) != 0 ) {
++it;
- buttonWidth = TQMAX( buttonWidth, o->tqsizeHint().width() );
- buttonHeight = TQMAX( buttonHeight, o->tqsizeHint().height() );
+ buttonWidth = TQMAX( buttonWidth, o->sizeHint().width() );
+ buttonHeight = TQMAX( buttonHeight, o->sizeHint().height() );
}
// calculate the optimal width
@@ -217,19 +217,19 @@ int ButtonFlowLayout::doLayout( const TQRect &r, bool testonly )
}
-TQSize ButtonFlowLayout::tqminimumSize() const
+TQSize ButtonFlowLayout::minimumSize() const
{
- return tqminimumSize(tqgeometry().size());
+ return minimumSize(tqgeometry().size());
}
-TQSize ButtonFlowLayout::tqminimumSize(const TQSize &r) const
+TQSize ButtonFlowLayout::minimumSize(const TQSize &r) const
{
TQSize s(0, 0);
for (TQPtrListIterator<TQLayoutItem> it(list); it.current(); ++it) {
TQLayoutItem *o = it.current();
- s = s.expandedTo( o->tqsizeHint()); //tqminimumSize() );
+ s = s.expandedTo( o->sizeHint()); //minimumSize() );
}
s.setHeight(heightForWidth(r.width()));
diff --git a/kradio3/plugins/gui-standard-display/displaycfg.cpp b/kradio3/plugins/gui-standard-display/displaycfg.cpp
index 0e92da7..16ebad2 100644
--- a/kradio3/plugins/gui-standard-display/displaycfg.cpp
+++ b/kradio3/plugins/gui-standard-display/displaycfg.cpp
@@ -48,16 +48,16 @@ DisplayConfiguration::DisplayConfiguration(TQWidget *parent)
TQLabel *l2 = new TQLabel(i18n("Inactive Text"), bg);
TQLabel *l3 = new TQLabel(i18n("Background Color"), bg);
- l1->tqsetAlignment(TQLabel::AlignCenter);
- l2->tqsetAlignment(TQLabel::AlignCenter);
- l3->tqsetAlignment(TQLabel::AlignCenter);
+ l1->setAlignment(TQLabel::AlignCenter);
+ l2->setAlignment(TQLabel::AlignCenter);
+ l3->setAlignment(TQLabel::AlignCenter);
- l1->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
- l2->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
- l3->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
- m_btnActive ->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
- m_btnInactive->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
- m_btnBkgnd ->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
+ l1->setSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
+ l2->setSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
+ l3->setSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed));
+ m_btnActive ->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
+ m_btnInactive->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
+ m_btnBkgnd ->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
m_btnActive ->setMinimumSize(TQSize(40, 40));
m_btnInactive->setMinimumSize(TQSize(40, 40));
@@ -72,7 +72,7 @@ DisplayConfiguration::DisplayConfiguration(TQWidget *parent)
m_fontChooser = new KFontChooser(this, NULL, false, TQStringList(), true, 4);
m_fontChooser->setFont(queryDisplayFont());
- m_fontChooser->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
+ m_fontChooser->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
TQVBoxLayout *l = new TQVBoxLayout(this, 10);
l->addWidget(bg);
diff --git a/kradio3/plugins/gui-standard-display/radioview.cpp b/kradio3/plugins/gui-standard-display/radioview.cpp
index c5f12f2..65430b2 100644
--- a/kradio3/plugins/gui-standard-display/radioview.cpp
+++ b/kradio3/plugins/gui-standard-display/radioview.cpp
@@ -162,10 +162,10 @@ RadioView::RadioView(const TQString &name)
btnSnooze->setIconSet(SmallIconSet("kradio_zzz"));
btnPlugins->setIconSet(SmallIconSet("kradio_plugins"));
- widgetStacks[clsRadioSound] ->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Preferred));
- widgetStacks[clsRadioDisplay]->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred));
- widgetStacks[clsRadioSeek] ->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
- comboStations ->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+ widgetStacks[clsRadioSound] ->setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Preferred));
+ widgetStacks[clsRadioDisplay]->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred));
+ widgetStacks[clsRadioSeek] ->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+ comboStations ->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
comboStations->setMinimumHeight(28);
diff --git a/kradio3/plugins/gui-standard-display/radioview_frequencyradio.cpp b/kradio3/plugins/gui-standard-display/radioview_frequencyradio.cpp
index 17afde3..5afaf09 100644
--- a/kradio3/plugins/gui-standard-display/radioview_frequencyradio.cpp
+++ b/kradio3/plugins/gui-standard-display/radioview_frequencyradio.cpp
@@ -185,11 +185,11 @@ bool RadioViewFrequencyRadio::setDisplayColors(const TQColor &activeText,
if (parentWidget() && parentWidget()->backgroundPixmap() ){
KPixmapIO io;
TQImage i = io.convertToImage(*parentWidget()->backgroundPixmap());
- KImageEffect::fade(i, 0.5, tqcolorGroup().color(TQColorGroup::Dark));
+ KImageEffect::fade(i, 0.5, colorGroup().color(TQColorGroup::Dark));
setPaletteBackgroundPixmap(io.convertToPixmap(i));
setBackgroundOrigin(WindowOrigin);
} else {
- setBackgroundColor(tqcolorGroup().color(TQColorGroup::Button));
+ setBackgroundColor(colorGroup().color(TQColorGroup::Button));
}
if (change)
@@ -320,10 +320,10 @@ void RadioViewFrequencyRadio::drawContents(TQPainter *paint)
xx_sg = r.x() + margin,
xy_sg = r.y() + margin;
- TQPen activePen (tqcolorGroup().color(TQColorGroup::Text), penw);
- TQPen inactivePen (tqcolorGroup().color(TQColorGroup::Mid), penw);
- TQBrush activeBrush = tqcolorGroup().brush(TQColorGroup::Text);
- TQBrush inactiveBrush = tqcolorGroup().brush(TQColorGroup::Mid);
+ TQPen activePen (colorGroup().color(TQColorGroup::Text), penw);
+ TQPen inactivePen (colorGroup().color(TQColorGroup::Mid), penw);
+ TQBrush activeBrush = colorGroup().brush(TQColorGroup::Text);
+ TQBrush inactiveBrush = colorGroup().brush(TQColorGroup::Mid);
// draw stereo symbol
paint->setPen( (m_stereo && m_power) ? activePen : inactivePen);
diff --git a/kradio3/plugins/radio/radio-configuration-ui.ui b/kradio3/plugins/radio/radio-configuration-ui.ui
index 28e936e..5e8ed61 100644
--- a/kradio3/plugins/radio/radio-configuration-ui.ui
+++ b/kradio3/plugins/radio/radio-configuration-ui.ui
@@ -122,7 +122,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>10</height>
@@ -358,7 +358,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -395,7 +395,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>20</width>
<height>20</height>
@@ -415,7 +415,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>10</width>
<height>5</height>
@@ -434,7 +434,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>10</height>
@@ -481,7 +481,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>20</height>
@@ -541,7 +541,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>20</height>
@@ -683,7 +683,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kradio3/plugins/radio/radio-configuration.cpp b/kradio3/plugins/radio/radio-configuration.cpp
index 4cbf764..b4136b6 100644
--- a/kradio3/plugins/radio/radio-configuration.cpp
+++ b/kradio3/plugins/radio/radio-configuration.cpp
@@ -484,7 +484,7 @@ void RadioConfiguration::slotStorePresets()
void RadioConfiguration::slotLastChangeNow()
{
slotSetDirty();
- editLastChange->setDateTime(TQDateTime::tqcurrentDateTime());
+ editLastChange->setDateTime(TQDateTime::currentDateTime());
}
diff --git a/kradio3/plugins/recording/encoder_mp3.cpp b/kradio3/plugins/recording/encoder_mp3.cpp
index 8d76fe2..15bc06c 100644
--- a/kradio3/plugins/recording/encoder_mp3.cpp
+++ b/kradio3/plugins/recording/encoder_mp3.cpp
@@ -126,7 +126,7 @@ bool RecordingEncodingMP3::openOutput(const TQString &output)
if (!m_error) {
id3tag_init(m_LAMEFlags);
id3tag_add_v2(m_LAMEFlags);
- TQString title = m_RadioStation->name() + TQString().sprintf(" - %s", (TQDateTime::tqcurrentDateTime().toString(Qt::ISODate)).ascii());
+ TQString title = m_RadioStation->name() + TQString().sprintf(" - %s", (TQDateTime::currentDateTime().toString(Qt::ISODate)).ascii());
TQString comment = i18n("Recorded by KRadio");
size_t l = title.length() + comment.length() + 10;
m_ID3Tags = new char[l];
diff --git a/kradio3/plugins/recording/encoder_ogg.cpp b/kradio3/plugins/recording/encoder_ogg.cpp
index b51eedd..110238a 100644
--- a/kradio3/plugins/recording/encoder_ogg.cpp
+++ b/kradio3/plugins/recording/encoder_ogg.cpp
@@ -176,7 +176,7 @@ bool RecordingEncodingOgg::openOutput(const TQString &output)
vorbis_comment_init (&vc);
vorbis_comment_add_tag_new(&vc, "creator", "KRadio" VERSION);
vorbis_comment_add_tag_new(&vc, "title", m_RadioStation->longName().utf8());
- vorbis_comment_add_tag_new(&vc, "date", TQDateTime::tqcurrentDateTime().toString(Qt::ISODate));
+ vorbis_comment_add_tag_new(&vc, "date", TQDateTime::currentDateTime().toString(Qt::ISODate));
vorbis_analysis_headerout(&m_VorbisDSP, &vc,
&header_main, &header_comments, &header_codebooks);
diff --git a/kradio3/plugins/recording/recording-configuration-ui.ui b/kradio3/plugins/recording/recording-configuration-ui.ui
index e5ba41c..1c6ece2 100644
--- a/kradio3/plugins/recording/recording-configuration-ui.ui
+++ b/kradio3/plugins/recording/recording-configuration-ui.ui
@@ -66,7 +66,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>141</width>
<height>20</height>
@@ -107,7 +107,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>141</width>
<height>20</height>
@@ -222,7 +222,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>5</height>
@@ -263,7 +263,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>225</width>
<height>20</height>
@@ -321,7 +321,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>225</width>
<height>20</height>
@@ -454,7 +454,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>225</width>
<height>20</height>
@@ -473,7 +473,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>5</height>
@@ -563,7 +563,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -623,7 +623,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>380</width>
<height>20</height>
@@ -688,7 +688,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/kradio3/plugins/recording/recording-datamonitor.cpp b/kradio3/plugins/recording/recording-datamonitor.cpp
index 8f22b1a..00b4755 100644
--- a/kradio3/plugins/recording/recording-datamonitor.cpp
+++ b/kradio3/plugins/recording/recording-datamonitor.cpp
@@ -50,7 +50,7 @@ RecordingDataMonitor::RecordingDataMonitor(TQWidget *parent, const char *name)
setColors(TQColor(20, 244, 20),
TQColor(10, 117, 10));
- tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
+ setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding));
}
@@ -107,10 +107,10 @@ void RecordingDataMonitor::internalDrawContents(TQPainter &painter, bool repaint
if (m_channels <= 0) return;
TQRect r = contentsRect();
- TQPen activePen (tqcolorGroup().color(TQColorGroup::Text), 1);
- TQPen inactivePen (tqcolorGroup().color(TQColorGroup::Mid), 1);
- TQBrush activeBrush = tqcolorGroup().brush(TQColorGroup::Text);
- TQBrush inactiveBrush = tqcolorGroup().brush(TQColorGroup::Mid);
+ TQPen activePen (colorGroup().color(TQColorGroup::Text), 1);
+ TQPen inactivePen (colorGroup().color(TQColorGroup::Mid), 1);
+ TQBrush activeBrush = colorGroup().brush(TQColorGroup::Text);
+ TQBrush inactiveBrush = colorGroup().brush(TQColorGroup::Mid);
TQBrush yellowBrush(TQColor(255,255,0));
TQBrush orangeBrush(TQColor(255,192,0));
TQBrush redBrush (TQColor(255,0, 0));
@@ -223,11 +223,11 @@ bool RecordingDataMonitor::setColors(const TQColor &activeText,
if (parentWidget() && parentWidget()->backgroundPixmap() ){
KPixmapIO io;
TQImage i = io.convertToImage(*parentWidget()->backgroundPixmap());
- KImageEffect::fade(i, 0.5, tqcolorGroup().color(TQColorGroup::Dark));
+ KImageEffect::fade(i, 0.5, colorGroup().color(TQColorGroup::Dark));
setPaletteBackgroundPixmap(io.convertToPixmap(i));
setBackgroundOrigin(WindowOrigin);
} else {
- setBackgroundColor(tqcolorGroup().color(TQColorGroup::Button));
+ setBackgroundColor(colorGroup().color(TQColorGroup::Button));
}
return true;
diff --git a/kradio3/plugins/recording/recording-monitor.cpp b/kradio3/plugins/recording/recording-monitor.cpp
index 063a095..24c2e05 100644
--- a/kradio3/plugins/recording/recording-monitor.cpp
+++ b/kradio3/plugins/recording/recording-monitor.cpp
@@ -43,7 +43,7 @@ RecordingMonitor::RecordingMonitor(const TQString &name)
l0->addWidget( new TQLabel(i18n("SoundStream"), this), 0, 0);
l0->addWidget(m_comboSoundStreamSelector = new KComboBox( this), 0, 1);
l0->addWidget( new TQLabel(i18n("Status"), this), 1, 0);
- l0->addWidget(m_labeltqStatus = new TQLabel(i18n("<undefined>"), this), 1, 1);
+ l0->addWidget(m_labelStatus = new TQLabel(i18n("<undefined>"), this), 1, 1);
l0->addWidget( new TQLabel(i18n("Recording File"), this), 2, 0);
l0->addWidget(m_labelFileName = new TQLabel(i18n("<undefined>"), this), 2, 1);
l0->addWidget( new TQLabel(i18n("File Size"), this), 3, 0);
@@ -369,7 +369,7 @@ void RecordingMonitor::slotStreamSelected(int idx)
m_labelTime ->setEnabled(true);
m_labelRate ->setEnabled(true);
m_labelFileName ->setEnabled(true);
- m_labeltqStatus ->setEnabled(true);
+ m_labelStatus ->setEnabled(true);
} else {
m_dataMonitor ->setEnabled(false);
m_labelSize ->setEnabled(false);
@@ -377,7 +377,7 @@ void RecordingMonitor::slotStreamSelected(int idx)
m_labelTime ->setEnabled(false);
m_labelRate ->setEnabled(false);
m_labelFileName ->setEnabled(false);
- m_labeltqStatus ->setEnabled(false);
+ m_labelStatus ->setEnabled(false);
}
m_currentStream = id;
m_recording = false;
diff --git a/kradio3/plugins/recording/recording-monitor.h b/kradio3/plugins/recording/recording-monitor.h
index a979c02..5f9247a 100644
--- a/kradio3/plugins/recording/recording-monitor.h
+++ b/kradio3/plugins/recording/recording-monitor.h
@@ -105,7 +105,7 @@ protected:
TQLabel *m_labelTime;
TQLabel *m_labelRate;
TQLabel *m_labelFileName;
- TQLabel *m_labeltqStatus;
+ TQLabel *m_labelStatus;
TQPushButton *m_btnStartStop;
KComboBox *m_comboSoundStreamSelector;
diff --git a/kradio3/plugins/recording/recording.cpp b/kradio3/plugins/recording/recording.cpp
index ca11bfe..9707de9 100644
--- a/kradio3/plugins/recording/recording.cpp
+++ b/kradio3/plugins/recording/recording.cpp
@@ -529,7 +529,7 @@ bool Recording::startEncoder(SoundStreamID ssid, const RecordingConfig &cfg)
TQString station = rs ? rs->name() + "-" : "";
station.replace(TQRegExp("[/*?]"), "_");
- TQDate date = TQDate::tqcurrentDate();
+ TQDate date = TQDate::currentDate();
TQTime time = TQTime::currentTime();
TQString sdate;
diff --git a/kradio3/plugins/streaming/streaming-configuration-ui.ui b/kradio3/plugins/streaming/streaming-configuration-ui.ui
index 884e03c..591bc87 100644
--- a/kradio3/plugins/streaming/streaming-configuration-ui.ui
+++ b/kradio3/plugins/streaming/streaming-configuration-ui.ui
@@ -142,13 +142,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -173,13 +173,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -202,7 +202,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>10</width>
<height>10</height>
@@ -221,13 +221,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -252,13 +252,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -293,13 +293,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -324,13 +324,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -353,7 +353,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>10</width>
<height>10</height>
@@ -372,13 +372,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -403,13 +403,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>30</width>
<height>30</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>30</height>
@@ -658,7 +658,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
@@ -675,7 +675,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
@@ -692,7 +692,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
@@ -709,7 +709,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
@@ -726,7 +726,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
diff --git a/kradio3/plugins/timecontrol/timecontrol-configuration-ui.ui b/kradio3/plugins/timecontrol/timecontrol-configuration-ui.ui
index 15ecc20..c5b92b8 100644
--- a/kradio3/plugins/timecontrol/timecontrol-configuration-ui.ui
+++ b/kradio3/plugins/timecontrol/timecontrol-configuration-ui.ui
@@ -62,7 +62,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -273,7 +273,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>100</height>
@@ -358,7 +358,7 @@
<property name="name">
<cstring>pixmapAlarmStation</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>20</width>
<height>20</height>
@@ -378,7 +378,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>150</width>
<height>20</height>
diff --git a/kradio3/plugins/timecontrol/timecontrol-configuration.cpp b/kradio3/plugins/timecontrol/timecontrol-configuration.cpp
index 31ec3db..c72aa5e 100644
--- a/kradio3/plugins/timecontrol/timecontrol-configuration.cpp
+++ b/kradio3/plugins/timecontrol/timecontrol-configuration.cpp
@@ -371,7 +371,7 @@ void TimeControlConfiguration::slotAlarmSelectChanged(int idx)
void TimeControlConfiguration::slotNewAlarm()
{
- TQDateTime dt(TQDateTime::tqcurrentDateTime());
+ TQDateTime dt(TQDateTime::currentDateTime());
Alarm a(dt, false, false);
alarms.push_back(a);
listAlarms->insertItem(a.alarmTime().toString());
diff --git a/kradio3/plugins/timecontrol/timecontrol.cpp b/kradio3/plugins/timecontrol/timecontrol.cpp
index 276e602..e5f99cf 100644
--- a/kradio3/plugins/timecontrol/timecontrol.cpp
+++ b/kradio3/plugins/timecontrol/timecontrol.cpp
@@ -102,7 +102,7 @@ bool TimeControl::setCountdownSeconds(int n)
bool TimeControl::startCountdown()
{
- m_countdownEnd = TQDateTime::tqcurrentDateTime().addSecs(m_countdownSeconds);
+ m_countdownEnd = TQDateTime::currentDateTime().addSecs(m_countdownSeconds);
m_countdownTimer.start(m_countdownSeconds * 1000, true);
notifyCountdownStarted(getCountdownEnd());
@@ -134,7 +134,7 @@ TQDateTime TimeControl::getNextAlarmTime() const
const Alarm *TimeControl::getNextAlarm () const
{
- TQDateTime now = TQDateTime::tqcurrentDateTime(),
+ TQDateTime now = TQDateTime::currentDateTime(),
next;
const Alarm *retval = NULL;
@@ -180,7 +180,7 @@ void TimeControl::slotQTimerAlarmTimeout()
notifyAlarm(*m_waitingFor);
}
- TQDateTime now = TQDateTime::tqcurrentDateTime();
+ TQDateTime now = TQDateTime::currentDateTime();
Alarm const *n = getNextAlarm();
TQDateTime na = getNextAlarmTime();
diff --git a/kradio3/plugins/timeshifter/timeshifter-configuration-ui.ui b/kradio3/plugins/timeshifter/timeshifter-configuration-ui.ui
index 2020bbc..c6b6109 100644
--- a/kradio3/plugins/timeshifter/timeshifter-configuration-ui.ui
+++ b/kradio3/plugins/timeshifter/timeshifter-configuration-ui.ui
@@ -40,7 +40,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>21</height>
@@ -57,7 +57,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>104</width>
<height>21</height>
@@ -133,7 +133,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>26</width>
<height>26</height>
@@ -166,7 +166,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>21</height>
@@ -183,7 +183,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>21</height>
@@ -202,7 +202,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>61</height>
diff --git a/kradio3/plugins/v4lradio/v4lradio-configuration-ui.ui b/kradio3/plugins/v4lradio/v4lradio-configuration-ui.ui
index 06550c7..9baedf3 100644
--- a/kradio3/plugins/v4lradio/v4lradio-configuration-ui.ui
+++ b/kradio3/plugins/v4lradio/v4lradio-configuration-ui.ui
@@ -53,7 +53,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>21</height>
@@ -86,7 +86,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>21</height>
@@ -103,7 +103,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>21</height>
@@ -120,7 +120,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>21</height>
@@ -137,7 +137,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>21</height>
@@ -154,7 +154,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>152</width>
<height>21</height>
@@ -292,7 +292,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>5</width>
<height>5</height>
@@ -549,7 +549,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>5</height>
@@ -615,7 +615,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -643,7 +643,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -705,7 +705,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -733,7 +733,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -795,7 +795,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -823,7 +823,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -874,7 +874,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>33</height>
@@ -911,7 +911,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>33</height>
diff --git a/kradio3/plugins/gui-quickbar/buttonflowlayout.h b/kradio3/plugins/gui-quickbar/buttonflowlayout.h
index fe33efc..bca27f0 100644
--- a/kradio3/plugins/gui-quickbar/buttonflowlayout.h
+++ b/kradio3/plugins/gui-quickbar/buttonflowlayout.h
@@ -41,9 +41,9 @@ public:
void addItem( TQLayoutItem *item);
bool hasHeightForWidth() const;
int heightForWidth( int ) const;
- TQSize tqsizeHint() const;
- TQSize tqminimumSize() const;
- TQSize tqminimumSize(const TQSize &r) const; // tqminimumSize is dependent from width
+ TQSize sizeHint() const;
+ TQSize minimumSize() const;
+ TQSize minimumSize(const TQSize &r) const; // minimumSize is dependent from width
TQLayoutIterator iterator();
TQSizePolicy::ExpandData expanding() const;
diff --git a/kradio3/plugins/gui-quickbar/quickbar.cpp b/kradio3/plugins/gui-quickbar/quickbar.cpp
index ca1d4d8..a5b0340 100644
--- a/kradio3/plugins/gui-quickbar/quickbar.cpp
+++ b/kradio3/plugins/gui-quickbar/quickbar.cpp
@@ -303,7 +303,7 @@ void QuickBar::rebuildGUI()
else
b->setText(m_showShortName ? rs.shortName() : rs.name());
- b->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred));
+ b->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Preferred));
TQToolTip::add(b, rs.longName());
if (isVisible()) b->show();
@@ -367,7 +367,7 @@ void QuickBar::setGeometry (int x, int y, int w, int h)
{
if (m_layout) {
TQSize marginSize(m_layout->margin()*2, m_layout->margin()*2);
- setMinimumSize(m_layout->tqminimumSize(TQSize(w, h) - marginSize) + marginSize);
+ setMinimumSize(m_layout->minimumSize(TQSize(w, h) - marginSize) + marginSize);
}
TQWidget::setGeometry (x, y, w, h);
}
@@ -381,10 +381,10 @@ void QuickBar::setGeometry (const TQRect &r)
void QuickBar::resizeEvent (TQResizeEvent *e)
{
// tqminimumSize might change because of the flow tqlayout
if (m_layout) {
TQSize marginSize(m_layout->margin()*2, m_layout->margin()*2);
- setMinimumSize(m_layout->tqminimumSize(e->size() - marginSize) + marginSize);
+ setMinimumSize(m_layout->minimumSize(e->size() - marginSize) + marginSize);
}
TQWidget::resizeEvent (e);
@@ -381,10 +381,10 @@ void QuickBar::setGeometry (const TQRect &r)
void QuickBar::resizeEvent (TQResizeEvent *e)
{
- // tqminimumSize might change because of the flow tqlayout
+ // minimumSize might change because of the flow tqlayout
if (m_layout) {
TQSize marginSize(m_layout->margin()*2, m_layout->margin()*2);